package com.weilab.biology.core.data.dto;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.weilab.biology.core.data.po.AppConfig;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.File;
import java.io.Serializable;

/**
 * 应用配置信息Dto
 *
 * @author yurui
 * @date 2023/5/5
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class AppConfigDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 应用ID
     */
    private Integer appId;

    /**
     * 应用名
     */
    private String appName;

    /**
     * 并发数
     */
    private Integer concurrentNum;

    /**
     * 命令行
     */
    private String cmd;

    /**
     * 任务超时时间(单位:分钟)
     */
    private Long timeout;

    /**
     * 放置文件的路径
     */
    private String localPath;

    /**
     * 放置请求参数文件的路径
     */
    private String requestPath;

    /**
     * 放置结果文件的路径
     */
    private String resultPath;

    /**
     * 放置日志文件的路径
     */
    private String logPath;

    /**
     * 邮件格式(json格式:{"subject":"**","success":"**"})
     */
    private JSONObject emailTemplate;


    public static AppConfigDto parse(AppConfig o) {
        if (o == null) {
            return null;
        }
        return new AppConfigDto()
                .setAppId(o.getAppId())
                .setAppName(o.getAppName())
                .setConcurrentNum(o.getConcurrentNum())
                .setCmd(o.getCmd())
                .setTimeout(o.getTimeout())
                .setLocalPath(o.getLocalPath())
                .setRequestPath(o.getLocalPath() + File.separator + "request" + File.separator)
                .setResultPath(o.getLocalPath() + File.separator + "result" + File.separator)
                .setLogPath(o.getLocalPath() + File.separator + "log" + File.separator)
                .setEmailTemplate(JSON.parseObject(o.getEmailTemplate()));
    }

}
